# plaidcloud-rpc
Common utilities for connecting to PlaidCloud's rpc interface

Documentation available at [https://plaidcloud.com/docs/plaidcloud-rpc/](https://plaidcloud.com/docs/plaidcloud-rpc/)

<hr>

Installation
===============

### UNIX (Linux/Mac OSX)

To install, run:

```
sudo pip install plaidcloud-utilities
```

### Windows

1. Open Anaconda command prompt as Administrator (this is equiv to sudo access)

2. Navigate to the repo

3. Enter the following command:

``` pip install plaidcloud-utilities```
